@@ -33,11 +33,13 @@ class Velocimetry(ORCBase):
             filter_velocity=True,
             filter_corr=True,
             filter_neighbour=True,
+            filter_count=True,
             kwargs_corr={},
             kwargs_std={},
             kwargs_angle={},
             kwargs_velocity={},
             kwargs_neighbour={},
+            kwargs_count={},
             inplace=False
     ):
         """Masks values using several filters that use temporal variations or comparison as basis.
@@ -80,7 +82,8 @@ class Velocimetry(ORCBase):
 
         """
         # load dataset in memory and update self
-        ds = copy.deepcopy(self._obj.load())
+        ds = copy.deepcopy(self._obj)
+        ds.load()
         # start with entirely independent filters
         if filter_corr:
             ds.velocimetry.filter_temporal_corr(v_x=v_x, v_y=v_y, **kwargs_corr)
@@ -88,11 +91,14 @@ class Velocimetry(ORCBase):
             ds.velocimetry.filter_temporal_velocity(v_x=v_x, v_y=v_y, **kwargs_velocity)
         if filter_neighbour:
             ds.velocimetry.filter_temporal_neighbour(v_x=v_x, v_y=v_y, **kwargs_neighbour)
-        # finalize with temporally dependent filters
+        # continue with temporally dependent filters
         if filter_std:
             ds.velocimetry.filter_temporal_std(v_x=v_x, v_y=v_y, **kwargs_std)
         if filter_angle:
             ds.velocimetry.filter_temporal_angle(v_x=v_x, v_y=v_y, **kwargs_angle)
+        # finalize with absolute count threshold filter
+        if filter_count:
+            ds.velocimetry.filter_temporal_count(**kwargs_count)
         ds.attrs = self._obj.attrs
         if inplace:
             self._obj.update(ds)
@@ -286,6 +292,26 @@ class Velocimetry(ORCBase):
         self._obj[v_y] = self._obj[v_y].where(self._obj[corr] > tolerance)
         # return ds
 
+    def filter_temporal_count(self, tolerance=0.33):
+        """Masks values with a too low correlation.
+
+        Parameters
+        ----------
+        tolerance : float (0-1)
+            tolerance for fractional amount of valid velocities after all filters. If less than the fraction is
+            available, the entire velocity will be set to missings.
+
+        Returns
+        -------
+        ds_filter : xr.Dataset
+            count filtered velocity vectors as [time, y, x]
+        """
+        # pass
+        count_filter = copy.deepcopy(self._obj["v_x"].count(dim="time") > tolerance * len(self._obj.time))
+        self._obj["v_x"] = self._obj["v_x"].where(count_filter)
+        self._obj["v_y"] = self._obj["v_y"].where(count_filter)
+
+
     def filter_spatial(
             self,
             v_x="v_x",
@@ -438,14 +464,19 @@ class Velocimetry(ORCBase):
 
 
     def get_transect(
-            self, x, y, z=None,
+            self, x, y, z=None, s=None,
             crs=None,
             v_eff=True,
             xs="xs",
             ys="ys",
             distance=None,
             wdw=1,
+            wdw_x_min=None,
+            wdw_x_max=None,
+            wdw_y_min=None,
+            wdw_y_max=None,
             rolling=None,
+            tolerance=0.5,
             quantiles=[0.05, 0.25, 0.5, 0.75, 0.95]
     ):
         """Interpolate all variables to supplied x and y coordinates of a cross section. This function assumes that the
@@ -463,6 +494,9 @@ class Velocimetry(ORCBase):
             y-coordinates on which interpolation should be done
         z : tuple or list-like
             z-coordinates on which interpolation should be done, defaults: None
+        s : tuple or list-like
+            distance from bank coordinates on which interpolation should be done, defaults: None
+            if set, these distances will be precisely respected, and not interpolated. ``distance`` will be ignored.
         crs : int, dict or str, optional
             coordinate reference system (e.g. EPSG code) in which x, y and z are measured (default: None),
             None assumes crs is the same as crs of xr.Dataset.
@@ -475,8 +509,22 @@ class Velocimetry(ORCBase):
         distance : float, optional
             sampling distance over the cross-section in [m]. the bathymetry points will be interpolated to match this
             distance. If not set, the distance will be estimated from the velocimetry grid resolution. (default: None)
-        wdw : int, window size to use for sampling the velocity. zero means, only cell itself, 1 means 3x3 window.
-            (default: 1)
+        wdw : int, optional
+            window size to use for sampling the velocity. zero means, only cell itself, 1 means 3x3 window.
+            (default: 1) wdw is used to fill wdw_x_min and wdwd_y_min with its negative (-wdw) value, and wdw_y_min and
+            wdw_y_max with its positive value, to create a sampling window.
+        wdw_x_min : int, optional
+            window size in negative x-direction of grid (must be negative), overrules wdw in negative x-direction if set
+        wdw_x_max : int, optional
+            window size in positive x-direction of grid, overrules wdw in positive x-direction if set
+        wdw_y_min : int, optional
+            window size in negative y-direction of grid (must be negative), overrules wdw in negative y-direction if set
+        wdw_y_max : int, optional
+            window size in positive y-direction of grid, overrules wdw in positive x-direction if set.
+        tolerance : float (0-1), optional
+            tolerance on the required amount of sampled data in the window defined by wdw and/or wdw_x_min, wdw_x_max,
+            wdw_y_min and wdw_y_max (if set). At least this fraction of cells each time step must have a data value
+            to return a value. Otherwise the location is given a nan as value.
         rolling : int, optional
             if set other than None (default), a rolling mean over time is applied, before deriving quantile estimates.
         quantiles : list of floats (0-1), optional
@@ -487,6 +535,12 @@ class Velocimetry(ORCBase):
         ds_points: xr.Dataset
             interpolated data at the supplied x and y coordinates over quantiles
         """
+        # set strides
+        wdw_x_min = -wdw if wdw_x_min is None else wdw_x_min
+        wdw_x_max = wdw if wdw_x_max is None else wdw_x_max
+        wdw_y_min = -wdw if wdw_y_min is None else wdw_y_min
+        wdw_y_max = wdw if wdw_y_max is None else wdw_y_max
+
         transform = helpers.affine_from_grid(self._obj[xs].values, self._obj[ys].values)
         if crs is not None:
             # transform coordinates of cross section
@@ -496,11 +550,12 @@ class Velocimetry(ORCBase):
                 crs_to=CRS.from_wkt(self.camera_config.crs)
             ))
             x, y = list(x), list(y)
-        if distance is None:
-            # interpret suitable sampling distance from grid resolution
-            distance = np.abs(np.diff(self._obj.x)[0])
-            # interpolate to a suitable set of points
-        x, y, z, s = helpers.xy_equidistant(x, y, distance=distance, z=z)
+        if s is None:
+            if distance is None:
+                # interpret suitable sampling distance from grid resolution
+                distance = np.abs(np.diff(self._obj.x)[0])
+                # interpolate to a suitable set of points
+            x, y, z, s = helpers.xy_equidistant(x, y, distance=distance, z=z)
 
         # make a cols and rows temporary variable
         coli, rowi = np.meshgrid(np.arange(len(self._obj["x"])), np.arange(len(self._obj["y"])))
@@ -531,17 +586,28 @@ class Velocimetry(ORCBase):
 
         # interpolate velocities over points
         if wdw == 0:
-            ds_points = self._obj.interp(x=_x, y=_y)
+            ds_points = self._obj.interp(x=_x, y=_y, method="nearest")
         else:
             # collect points within a stride, collate and analyze for outliers
-            ds_wdw = xr.concat([self._obj.shift(x=x_stride, y=y_stride) for x_stride in range(-wdw, wdw + 1) for y_stride in
-                                range(-wdw, wdw + 1)], dim="stride")
+            ds_wdw = xr.concat([self._obj.shift(x=x_stride, y=y_stride) for x_stride in range(wdw_x_min, wdw_x_max + 1) for y_stride in
+                                range(wdw_y_min, wdw_y_max + 1)], dim="stride")
             # use the median (not mean) to prevent a large influence of serious outliers
-            ds_effective = ds_wdw.mean(dim="stride", keep_attrs=True)
+            missing_tolerance = ds_wdw.mean(dim="time").count(dim="stride") > tolerance * len(ds_wdw.stride)
+            # missing_tolerance = ds_wdw.count(dim="stride") > tolerance*len(ds_wdw.stride)
+            ds_effective = ds_wdw.median(dim="stride", keep_attrs=True)
+            # remove velocities that are too few in samples
+            ds_effective = ds_effective.where(missing_tolerance)
+            # scipy does not tolerate np.float32 since scipy=1.10.0, so first convert to np.float64
+            for var in ds_effective:
+                ds_effective[var] = ds_effective[var].astype(np.float64)
+            for coord in ds_effective.coords:
+                ds_effective[coord] = ds_effective[coord].astype(np.float64)
+
             ds_points = ds_effective.interp(x=_x, y=_y)
         if np.isnan(ds_points["v_x"].mean(dim="time")).all():
-            raise ValueError(
-                "No valid velocimetry points found over bathymetry. Check if the bethymetry is within the camera objective")
+            warnings.warn(
+                "No valid velocimetry points found over bathymetry. Check if the bathymetry is within the camera objective or anything is visible in objective."
+            )
         # add the xcoords and ycoords (and zcoords if available) originally assigned so that even points outside the grid covered by ds can be
         # found back from this dataset
         ds_points = ds_points.assign_coords(xcoords=("points", list(x)))
